@@ -1,7 +1,7 @@
 #' Term frequency of tokens
 #'
 #' `step_texthash` creates a *specification* of a recipe step that
-#'  will convert a [tokenlist] into multiple variables using the 
+#'  will convert a [tokenlist] into multiple variables using the
 #'  hashing trick.
 #'
 #' @param recipe A recipe object. The step will be added to the
@@ -12,12 +12,12 @@
 #'  details. For the `tidy` method, these are not currently used.
 #' @param role For model terms created by this step, what analysis
 #'  role should they be assigned?. By default, the function assumes
-#'  that the new columns created by the original variables will be 
+#'  that the new columns created by the original variables will be
 #'  used as predictors in a model.
 #' @param columns A list of tibble results that define the
 #'  encoding. This is `NULL` until the step is trained by
 #'  [recipes::prep.recipe()].
-#' @param signed A logical, indicating whether to use a signed 
+#' @param signed A logical, indicating whether to use a signed
 #' hash-function to reduce collisions when hashing. Defaults to TRUE.
 #' @param num_terms An integer, the number of variables to output.
 #'  Defaults to 1024.
@@ -37,46 +37,46 @@
 #'  to the sequence of existing steps (if any).
 #' @examples
 #' if (requireNamespace("text2vec", quietly = TRUE)) {
-#' library(recipes)
-#' library(modeldata)
-#' data(okc_text)
-#' 
-#' okc_rec <- recipe(~ ., data = okc_text) %>%
-#'   step_tokenize(essay0) %>%
-#'   step_tokenfilter(essay0, max_tokens = 10) %>%
-#'   step_texthash(essay0)
-#'   
-#' okc_obj <- okc_rec %>%
-#'   prep()
-#'   
-#' bake(okc_obj, okc_text)
-#' 
-#' tidy(okc_rec, number = 2)
-#' tidy(okc_obj, number = 2)
+#'   library(recipes)
+#'   library(modeldata)
+#'   data(okc_text)
+#'
+#'   okc_rec <- recipe(~., data = okc_text) %>%
+#'     step_tokenize(essay0) %>%
+#'     step_tokenfilter(essay0, max_tokens = 10) %>%
+#'     step_texthash(essay0)
+#'
+#'   okc_obj <- okc_rec %>%
+#'     prep()
+#'
+#'   bake(okc_obj, okc_text)
+#'
+#'   tidy(okc_rec, number = 2)
+#'   tidy(okc_obj, number = 2)
 #' }
 #' @export
 #' @details
-#' Feature hashing, or the hashing trick, is a transformation of a 
+#' Feature hashing, or the hashing trick, is a transformation of a
 #' text variable into a new set of numerical variables. This is done by
 #' applying a hashing function over the tokens and using the hash values
 #' as feature indices. This allows for a low memory representation of the
-#' text. This implementation is done using the MurmurHash3 method. 
-#' 
-#' The argument `num_terms` controls the number of indices that the hashing 
-#' function will map to. This is the tuning parameter for this 
+#' text. This implementation is done using the MurmurHash3 method.
+#'
+#' The argument `num_terms` controls the number of indices that the hashing
+#' function will map to. This is the tuning parameter for this
 #' transformation. Since the hashing function can map two different tokens
-#' to the same index, will a higher value of `num_terms` result in a lower 
+#' to the same index, will a higher value of `num_terms` result in a lower
 #' chance of collision.
-#' 
+#'
 #' The new components will have names that begin with `prefix`, then
 #' the name of the variable, followed by the tokens all separated by
 #' `-`. The variable names are padded with zeros. For example,
 #' if `num_terms < 10`, their names will be `hash1` - `hash9`.
 #' If `num_terms = 101`, their names will be `hash001` - `hash101`.
-#' 
-#' @references Kilian Weinberger; Anirban Dasgupta; John Langford; 
+#'
+#' @references Kilian Weinberger; Anirban Dasgupta; John Langford;
 #'  Alex Smola; Josh Attenberg (2009).
-#'  
+#'
 #' @seealso [step_tokenize()] to turn character into tokenlist.
 #' @family tokenlist to numeric steps
 step_texthash <-
@@ -90,9 +90,8 @@ step_texthash <-
            prefix = "hash",
            skip = FALSE,
            id = rand_id("texthash")) {
+    recipes::recipes_pkg_check(required_pkgs.step_texthash())
 
-    recipes::recipes_pkg_check("text2vec")
-    
     add_step(
       recipe,
       step_texthash_new(
@@ -109,8 +108,10 @@ step_texthash <-
     )
   }
 
-hash_funs <- c("md5", "sha1", "crc32", "sha256", "sha512", "xxhash32",
-               "xxhash64", "murmur32")
+hash_funs <- c(
+  "md5", "sha1", "crc32", "sha256", "sha512", "xxhash32",
+  "xxhash64", "murmur32"
+)
 
 step_texthash_new <-
   function(terms, role, trained, columns, signed, num_terms, prefix, skip,
@@ -154,16 +155,19 @@ bake.step_texthash <- function(object, new_data, ...) {
   # for backward compat
 
   for (i in seq_along(col_names)) {
-
-    tf_text <- hashing_function(get_tokens(new_data[, col_names[i], drop = TRUE]),
-                                paste0(col_names[i], "_",
-                                       names0(object$num_terms, object$prefix)),
-                                object$signed,
-                                object$num_terms)
+    tf_text <- hashing_function(
+      get_tokens(new_data[, col_names[i], drop = TRUE]),
+      paste0(
+        col_names[i], "_",
+        names0(object$num_terms, object$prefix)
+      ),
+      object$signed,
+      object$num_terms
+    )
 
     new_data <-
       new_data[, !(colnames(new_data) %in% col_names[i]), drop = FALSE]
-    
+
     new_data <- vctrs::vec_cbind(tf_text, new_data)
   }
 
@@ -183,14 +187,18 @@ print.step_texthash <-
 #' @export
 tidy.step_texthash <- function(x, ...) {
   if (is_trained(x)) {
-    res <- tibble(terms = x$terms,
-                  value = x$signed,
-                  length = x$num_terms)
+    res <- tibble(
+      terms = x$terms,
+      value = x$signed,
+      length = x$num_terms
+    )
   } else {
     term_names <- sel2char(x$terms)
-    res <- tibble(terms = term_names,
-                  value = na_lgl,
-                  length = na_int)
+    res <- tibble(
+      terms = term_names,
+      value = na_lgl,
+      length = na_int
+    )
   }
   res$id <- x$id
   res
@@ -198,9 +206,8 @@ tidy.step_texthash <- function(x, ...) {
 
 # Implementation
 hashing_function <- function(data, labels, signed, n) {
-  
   counts <- list_to_hash(data, n, signed)
-  
+
   colnames(counts) <- labels
   as_tibble(counts)
 }
@@ -212,3 +219,38 @@ list_to_hash <- function(x, n, signed) {
   as.matrix(text2vec::create_dtm(it, vectorizer))
 }
 
+
+#' S3 methods for tracking which additional packages are needed for steps.
+#'
+#' Recipe-adjacent packages always list themselves as a required package so that
+#' the steps can function properly within parallel processing schemes.
+#' @param x A recipe step
+#' @return A character vector
+#' @rdname required_pkgs.step
+#' @keywords internal
+#' @export
+required_pkgs.step_texthash <- function(x, ...) {
+  c("text2vec", "textrecipes")
+}
+
+#' Find recommended methods for generating parameter values
+#'
+#' [tunable()] determines which parameters in an object _can_ be tuned along
+#' with information about the parameters.
+#' @param x A recipe step
+#' @param ... Not currently used.
+#' @rdname tunable.step
+#' @keywords internal
+#' @export
+tunable.step_texthash <- function(x, ...) {
+  tibble::tibble(
+    name = c("signed", "num_terms"),
+    call_info = list(
+      list(pkg = "dials", fun = "signed_hash"),
+      list(pkg = "dials", fun = "num_hash", range = c(8, 12))
+    ),
+    source = "recipe",
+    component = "step_texthash",
+    component_id = x$id
+  )
+}
