@@ -14,10 +14,10 @@
 #' @param columns A list of tibble results that define the
 #'  encoding. This is `NULL` until the step is trained by
 #'  [recipes::prep.recipe()].
-#' @param num_tokens The number of tokens in the n-gram. This must be an integer 
+#' @param num_tokens The number of tokens in the n-gram. This must be an integer
 #'  greater than or equal to 1. Defaults to 3.
 #' @param min_num_tokens The minimum number of tokens in the n-gram.
-#'  This must be an integer greater than or equal to 1 and smaller than `n`. 
+#'  This must be an integer greater than or equal to 1 and smaller than `n`.
 #'  Defaults to 3.
 #' @param delim The separator between words in an n-gram. Defaults to "_".
 #' @param skip A logical. Should the step be skipped when the
@@ -30,40 +30,39 @@
 #' @param id A character string that is unique to this step to identify it.
 #' @param trained A logical to indicate if the recipe has been
 #'  baked.
-#'  
-#' @details 
+#'
+#' @details
 #'  The use of this step will leave the ordering of the tokens meaningless.
-#'  If `min_num_tokens <  num_tokens` then the tokens order in increasing 
+#'  If `min_num_tokens <  num_tokens` then the tokens order in increasing
 #'  fashion with respect to the number of tokens in the n-gram. If
-#'  `min_num_tokens = 1` and `num_tokens = 3` then the output contains all the 
+#'  `min_num_tokens = 1` and `num_tokens = 3` then the output contains all the
 #'  1-grams followed by all the 2-grams followed by all the 3-grams.
-#'  
+#'
 #' @return An updated version of `recipe` with the new step added
 #'  to the sequence of existing steps (if any).
 #' @examples
 #' library(recipes)
 #' library(modeldata)
 #' data(okc_text)
-#' 
-#' okc_rec <- recipe(~ ., data = okc_text) %>%
+#'
+#' okc_rec <- recipe(~., data = okc_text) %>%
 #'   step_tokenize(essay0) %>%
 #'   step_ngram(essay0)
-#'   
+#'
 #' okc_obj <- okc_rec %>%
 #'   prep()
-#' 
-#' juice(okc_obj, essay0) %>% 
+#'
+#' bake(okc_obj, new_data = NULL, essay0) %>%
 #'   slice(1:2)
-#' 
-#' juice(okc_obj) %>% 
-#'   slice(2) %>% 
-#'   pull(essay0) 
-#'   
+#'
+#' bake(okc_obj, new_data = NULL) %>%
+#'   slice(2) %>%
+#'   pull(essay0)
+#'
 #' tidy(okc_rec, number = 2)
 #' tidy(okc_obj, number = 2)
-#' 
 #' @export
-#' 
+#'
 #' @seealso [step_tokenize()] to turn character into tokenlist.
 #' @family tokenlist to tokenlist steps
 step_ngram <-
@@ -76,8 +75,7 @@ step_ngram <-
            min_num_tokens = 3L,
            delim = "_",
            skip = FALSE,
-           id = rand_id("ngram")
-  ) {
+           id = rand_id("ngram")) {
     add_step(
       recipe,
       step_ngram_new(
@@ -95,7 +93,7 @@ step_ngram <-
   }
 
 step_ngram_new <-
-  function(terms, role, trained, columns, num_tokens, min_num_tokens, delim, 
+  function(terms, role, trained, columns, num_tokens, min_num_tokens, delim,
            skip, id) {
     step(
       subclass = "ngram",
@@ -114,9 +112,9 @@ step_ngram_new <-
 #' @export
 prep.step_ngram <- function(x, training, info = NULL, ...) {
   col_names <- terms_select(x$terms, info = info)
-  
+
   check_list(training[, col_names])
-  
+
   step_ngram_new(
     terms = x$terms,
     role = x$role,
@@ -134,13 +132,15 @@ prep.step_ngram <- function(x, training, info = NULL, ...) {
 bake.step_ngram <- function(object, new_data, ...) {
   col_names <- object$columns
   # for backward compat
-  
+
   for (i in seq_along(col_names)) {
-    ngrammed_tokenlist <- tokenlist_ngram(new_data[, col_names[i], drop = TRUE],
-                                          n = object$num_tokens,
-                                          n_min = object$min_num_tokens,
-                                          delim = object$delim)
-    
+    ngrammed_tokenlist <- tokenlist_ngram(
+      x = new_data[, col_names[i], drop = TRUE],
+      n = object$num_tokens,
+      n_min = object$min_num_tokens,
+      delim = object$delim
+    )
+
     new_data[, col_names[i]] <- tibble(ngrammed_tokenlist)
   }
   new_data <- factor_to_text(new_data, col_names)
@@ -163,22 +163,22 @@ tidy.step_ngram <- function(x, ...) {
     res <- tibble(terms = x$terms)
   } else {
     term_names <- sel2char(x$terms)
-    res <- tibble(terms = term_names,
-                  value = na_chr)
+    res <- tibble(
+      terms = term_names,
+      value = na_chr
+    )
   }
   res$id <- x$id
   res
 }
 
-#' tunable methods for step_ngram
-#'
-#' These functions define what parameters _can_ be tuned for specific steps.
-#' They also define the recommended objects from the `dials` package that can
-#' be used to generate new parameter values and other characteristics.
-#' @param x A recipe step object
-#' @param ... Not used.
-#' @return A tibble object.
-#' @keywords internal
+#' @rdname required_pkgs.step
+#' @export
+required_pkgs.step_ngram <- function(x, ...) {
+  c("textrecipes")
+}
+
+#' @rdname tunable.step
 #' @export
 tunable.step_ngram <- function(x, ...) {
   tibble::tibble(
@@ -191,4 +191,3 @@ tunable.step_ngram <- function(x, ...) {
     component_id = x$id
   )
 }
-
