@@ -33,52 +33,52 @@
 #' library(recipes)
 #' library(modeldata)
 #' data(okc_text)
-#' 
-#' okc_rec <- recipe(~ ., data = okc_text) %>%
+#'
+#' okc_rec <- recipe(~., data = okc_text) %>%
 #'   step_tokenize(essay0) %>%
 #'   step_stem(essay0)
-#'   
+#'
 #' okc_obj <- okc_rec %>%
 #'   prep()
-#' 
-#' juice(okc_obj, essay0) %>% 
+#'
+#' bake(okc_obj, new_data = NULL, essay0) %>%
 #'   slice(1:2)
-#' 
-#' juice(okc_obj) %>% 
-#'   slice(2) %>% 
-#'   pull(essay0) 
-#'   
+#'
+#' bake(okc_obj, new_data = NULL) %>%
+#'   slice(2) %>%
+#'   pull(essay0)
+#'
 #' tidy(okc_rec, number = 2)
 #' tidy(okc_obj, number = 2)
-#' 
+#'
 #' # Using custom stemmer. Here a custom stemmer that removes the last letter
 #' # if it is a "s".
 #' remove_s <- function(x) gsub("s$", "", x)
-#' 
-#' okc_rec <- recipe(~ ., data = okc_text) %>%
+#'
+#' okc_rec <- recipe(~., data = okc_text) %>%
 #'   step_tokenize(essay0) %>%
 #'   step_stem(essay0, custom_stemmer = remove_s)
-#'   
+#'
 #' okc_obj <- okc_rec %>%
 #'   prep()
-#' 
-#' juice(okc_obj, essay0) %>% 
+#'
+#' bake(okc_obj, new_data = NULL, essay0) %>%
 #'   slice(1:2)
-#' 
-#' juice(okc_obj) %>% 
-#'   slice(2) %>% 
-#'   pull(essay0) 
+#'
+#' bake(okc_obj, new_data = NULL) %>%
+#'   slice(2) %>%
+#'   pull(essay0)
 #' @export
 #' @details
 #' Words tend to have different forms depending on context, such as
 #' organize, organizes, and organizing. In many situations it is beneficial
-#' to have these words condensed into one to allow for a smaller pool of 
-#' words. Stemming is the act of choping off the end of words using a set
+#' to have these words condensed into one to allow for a smaller pool of
+#' words. Stemming is the act of chopping off the end of words using a set
 #'  of heuristics.
-#' 
-#' Note that the steming will only be done at the end of the word and 
+#'
+#' Note that the stemming will only be done at the end of the word and
 #' will therefore not work reliably on ngrams or sentences.
-#' 
+#'
 #' @seealso [step_tokenize()] to turn character into tokenlist.
 #' @family tokenlist to tokenlist steps
 step_stem <-
@@ -90,8 +90,7 @@ step_stem <-
            options = list(),
            custom_stemmer = NULL,
            skip = FALSE,
-           id = rand_id("stem")
-  ) {
+           id = rand_id("stem")) {
     add_step(
       recipe,
       step_stem_new(
@@ -149,8 +148,10 @@ bake.step_stem <- function(object, new_data, ...) {
     SnowballC::wordStem
 
   for (i in seq_along(col_names)) {
-    stemmed_tokenlist <- tokenlist_apply(new_data[, col_names[i], drop = TRUE],
-                                         stem_fun, object$options)
+    stemmed_tokenlist <- tokenlist_apply(
+      new_data[, col_names[i], drop = TRUE],
+      stem_fun, object$options
+    )
 
     new_data[, col_names[i]] <- tibble(stemmed_tokenlist)
   }
@@ -164,20 +165,30 @@ print.step_stem <-
     cat("Stemming for ", sep = "")
     printer(x$columns, x$terms, x$trained, width = width)
     invisible(x)
-}
+  }
 
 #' @rdname step_stem
 #' @param x A `step_stem` object.
 #' @export
 tidy.step_stem <- function(x, ...) {
   if (is_trained(x)) {
-    res <- tibble(terms = x$terms,
-                  is_custom_stemmer = is.null(x$custom_stemmer))
+    res <- tibble(
+      terms = x$terms,
+      is_custom_stemmer = is.null(x$custom_stemmer)
+    )
   } else {
     term_names <- sel2char(x$terms)
-    res <- tibble(terms = term_names,
-                  value = na_chr)
+    res <- tibble(
+      terms = term_names,
+      value = na_chr
+    )
   }
   res$id <- x$id
   res
 }
+
+#' @rdname required_pkgs.step
+#' @export
+required_pkgs.step_stem <- function(x, ...) {
+  c("textrecipes", "SnowballC")
+}
