@@ -1,4 +1,4 @@
-#' text_normalizationming of [tokenlist] variables
+#' Normalization of [tokenlist] variables
 #'
 #' `step_text_normalization` creates a *specification* of a recipe step that
 #'  will perform Unicode Normalization
@@ -13,9 +13,9 @@
 #' @param columns A list of tibble results that define the
 #'  encoding. This is `NULL` until the step is trained by
 #'  [recipes::prep.recipe()].
-#' @param normalization_form A single character string determining the Unicode 
-#'  Normalization. Must be one of "nfc", "nfd", "nfkd", "nfkc", or 
-#'  "nfkc_casefold". Defaults to "nfc". 
+#' @param normalization_form A single character string determining the Unicode
+#'  Normalization. Must be one of "nfc", "nfd", "nfkd", "nfkc", or
+#'  "nfkc_casefold". Defaults to "nfc".
 #'  See [stringi::stri_trans_nfc()] for more details.
 #' @param skip A logical. Should the step be skipped when the
 #'  recipe is baked by [recipes::bake.recipe()]? While all
@@ -31,28 +31,28 @@
 #'  to the sequence of existing steps (if any).
 #' @examples
 #' if (requireNamespace("stringi", quietly = TRUE)) {
-#' library(recipes)
-#' 
-#' sample_data <- tibble(text = c("sch\U00f6n", "scho\U0308n"))
-#' 
-#' okc_rec <- recipe(~ ., data = sample_data) %>%
-#'   step_text_normalization(text)
-#'   
-#' okc_obj <- okc_rec %>%
-#'   prep()
-#' 
-#' juice(okc_obj, text) %>% 
-#'   slice(1:2)
-#' 
-#' juice(okc_obj) %>% 
-#'   slice(2) %>% 
-#'   pull(text) 
-#'   
-#' tidy(okc_rec, number = 1)
-#' tidy(okc_obj, number = 1)
+#'   library(recipes)
+#'
+#'   sample_data <- tibble(text = c("sch\U00f6n", "scho\U0308n"))
+#'
+#'   rec <- recipe(~., data = sample_data) %>%
+#'     step_text_normalization(text)
+#'
+#'   prepped <- rec %>%
+#'     prep()
+#'
+#'   bake(prepped, new_data = NULL, text) %>%
+#'     slice(1:2)
+#'
+#'   bake(prepped, new_data = NULL) %>%
+#'     slice(2) %>%
+#'     pull(text)
+#'
+#'   tidy(rec, number = 1)
+#'   tidy(prepped, number = 1)
 #' }
 #' @export
-#' 
+#'
 #' @seealso [step_texthash()] for feature hashing.
 #' @family character to character steps
 step_text_normalization <-
@@ -63,11 +63,9 @@ step_text_normalization <-
            columns = NULL,
            normalization_form = "nfc",
            skip = FALSE,
-           id = rand_id("text_normalization")
-  ) {
-    
-    recipes::recipes_pkg_check("stringi")
-    
+           id = rand_id("text_normalization")) {
+    recipes::recipes_pkg_check(required_pkgs.step_text_normalization())
+
     add_step(
       recipe,
       step_text_normalization_new(
@@ -99,11 +97,11 @@ step_text_normalization_new <-
 #' @export
 prep.step_text_normalization <- function(x, training, info = NULL, ...) {
   col_names <- terms_select(x$terms, info = info)
-  
+
   training <- factor_to_text(training, col_names)
-  
+
   check_type(training[, col_names], quant = FALSE)
-  
+
   step_text_normalization_new(
     terms = x$terms,
     role = x$role,
@@ -119,9 +117,9 @@ prep.step_text_normalization <- function(x, training, info = NULL, ...) {
 bake.step_text_normalization <- function(object, new_data, ...) {
   col_names <- object$columns
   # for backward compat
-  
+
   new_data <- factor_to_text(new_data, col_names)
-  
+
   normalization_fun <- switch(
     object$normalization_form,
     nfc = stringi::stri_trans_nfc,
@@ -129,15 +127,17 @@ bake.step_text_normalization <- function(object, new_data, ...) {
     nfkd = stringi::stri_trans_nfkd,
     nfkc = stringi::stri_trans_nfkc,
     nfkc_casefold = stringi::stri_trans_nfkc_casefold,
-    rlang::abort(paste("'normalization_form' must be one of",
-                       "'nfc', 'nfd', 'nfkd', 'nfkc', or 'nfkc_casefold'",
-                       "but was ", object$normalization_form))
-    )
+    rlang::abort(paste(
+      "'normalization_form' must be one of",
+      "'nfc', 'nfd', 'nfkd', 'nfkc', or 'nfkc_casefold'",
+      "but was ", object$normalization_form
+    ))
+  )
 
   for (i in seq_along(col_names)) {
     new_data[, col_names[i]] <- normalization_fun(
-        getElement(new_data, col_names[i])
-      )
+      getElement(new_data, col_names[i])
+    )
   }
   new_data <- factor_to_text(new_data, col_names)
   as_tibble(new_data)
@@ -156,13 +156,24 @@ print.step_text_normalization <-
 #' @export
 tidy.step_text_normalization <- function(x, ...) {
   if (is_trained(x)) {
-    res <- tibble(terms = x$terms,
-                  normalization_form = x$normalization_form)
+    res <- tibble(
+      terms = x$terms,
+      normalization_form = x$normalization_form
+    )
   } else {
     term_names <- sel2char(x$terms)
-    res <- tibble(terms = term_names,
-                  value = na_chr)
+    res <- tibble(
+      terms = term_names,
+      value = na_chr
+    )
   }
   res$id <- x$id
   res
 }
+
+
+#' @rdname required_pkgs.step
+#' @export
+required_pkgs.step_text_normalization <- function(x, ...) {
+  c("stringi", "textrecipes")
+}
