@@ -1,6 +1,6 @@
 #' Create tokenlist object
-#' 
-#' A [tokenlist] object is a thin wrapper around a list of character vectors, 
+#'
+#' A [tokenlist] object is a thin wrapper around a list of character vectors,
 #' with a few attributes.
 #'
 #' @param tokens List of character vectors
@@ -13,16 +13,16 @@
 #' @examples
 #' abc <- list(letters, LETTERS)
 #' tokenlist(abc)
-#' 
+#'
 #' unclass(tokenlist(abc))
-#' 
+#'
 #' tibble(text = tokenlist(abc))
-#' 
+#'
 #' library(tokenizers)
 #' library(modeldata)
 #' data(okc_text)
 #' tokens <- tokenize_words(okc_text$essay0)
-#' 
+#'
 #' tokenlist(tokens)
 tokenlist <- function(tokens = list(), lemma = NULL, pos = NULL) {
   tokens <- vec_cast(tokens, list())
@@ -33,14 +33,15 @@ tokenlist <- function(tokens = list(), lemma = NULL, pos = NULL) {
     pos <- vec_cast(pos, list())
   }
   unique_tokens <- unique(unlist(tokens))
-  
-  new_tokenlist(tokens = tokens, lemma = lemma, pos = pos, 
-                unique_tokens = unique_tokens %||% character())
+
+  new_tokenlist(
+    tokens = tokens, lemma = lemma, pos = pos,
+    unique_tokens = unique_tokens %||% character()
+  )
 }
 
 new_tokenlist <- function(tokens = list(), lemma = NULL, pos = NULL,
                           unique_tokens = character()) {
-  
   vec_assert(tokens, list())
   if (!(is.null(lemma) | is.list(lemma))) {
     rlang::abort("`lemma` must be NULL or a list.")
@@ -49,18 +50,26 @@ new_tokenlist <- function(tokens = list(), lemma = NULL, pos = NULL,
     rlang::abort("`pos` must be NULL or a list.")
   }
   vec_assert(unique_tokens, character())
-  
-  if(length(tokens) == 0) {
-    return(vctrs::new_rcrd(list(tokens = tokens), 
-                           unique_tokens = unique_tokens,
-                           class = "textrecipes_tokenlist"))
+
+  if (length(tokens) == 0) {
+    return(vctrs::new_rcrd(
+      fields = list(tokens = tokens),
+      unique_tokens = unique_tokens,
+      class = "textrecipes_tokenlist"
+    ))
   }
-  
-  vctrs::new_rcrd(purrr::compact(list(tokens = tokens, 
-                                      lemma = lemma, 
-                                      pos = pos)), 
-           unique_tokens = unique_tokens,
-           class = "textrecipes_tokenlist")
+
+  vctrs::new_rcrd(
+    fields = purrr::compact(
+      list(
+        tokens = tokens,
+        lemma = lemma,
+        pos = pos
+      )
+    ),
+  unique_tokens = unique_tokens,
+  class = "textrecipes_tokenlist"
+  )
 }
 
 is_tokenlist <- function(x) {
@@ -92,16 +101,17 @@ get_unique_tokens <- function(x) {
 }
 
 #' @export
-vec_restore.textrecipes_tokenlist <- function(x, to, ..., 
+vec_restore.textrecipes_tokenlist <- function(x, to, ...,
                                               i = NULL) {
-  
   tokens <- get_tokens(x)
   unique_tokens <- unique(unlist(tokens))
 
-  new_tokenlist(tokens, 
-            maybe_get_lemma(x), 
-            maybe_get_pos(x),
-            unique_tokens %||% character())
+  new_tokenlist(
+    tokens,
+    maybe_get_lemma(x),
+    maybe_get_pos(x),
+    unique_tokens %||% character()
+  )
 }
 
 
@@ -119,10 +129,11 @@ vec_ptype_abbr.textrecipes_tokenlist <- function(x, ...) {
 
 #' @export
 obj_print_footer.textrecipes_tokenlist <- function(x, ...) {
-  cat("# Unique Tokens: ", 
-      format(length(attr(x, "unique_tokens"))), 
-      "\n", 
-      sep = "")
+  cat("# Unique Tokens: ",
+    format(length(attr(x, "unique_tokens"))),
+    "\n",
+    sep = ""
+  )
 }
 
 # Special functions -----------------------------------------------------------
@@ -133,11 +144,11 @@ tokenlist_filter <- function(x, dict, keep = FALSE) {
   if (!is_tokenlist(x)) {
     rlang::abort("Input must be a tokenlist.")
   }
-  
+
   if (!keep) {
     dict <- setdiff(attr(x, "unique_tokens"), dict)
   }
-  
+
   tokens <- get_tokens(x)
   seq_x <- seq_along(tokens)
   i <- rep(seq_x, lengths(tokens))
@@ -145,10 +156,10 @@ tokenlist_filter <- function(x, dict, keep = FALSE) {
 
   keep_id <- !is.na(j)
   split_id <- factor(i[keep_id], seq_x)
-  
+
   out <- split(dict[j[keep_id]], split_id)
   names(out) <- NULL
-  
+
   lemma <- maybe_get_lemma(x)
   if (!is.null(lemma)) {
     lemma <- split(unlist(lemma)[keep_id], split_id)
@@ -156,7 +167,7 @@ tokenlist_filter <- function(x, dict, keep = FALSE) {
   } else {
     lemma <- NULL
   }
-  
+
   pos <- maybe_get_pos(x)
   if (!is.null(pos)) {
     pos <- split(unlist(pos)[keep_id], split_id)
@@ -164,7 +175,7 @@ tokenlist_filter <- function(x, dict, keep = FALSE) {
   } else {
     pos <- NULL
   }
-  
+
   new_tokenlist(out, lemma = lemma, pos = pos, unique_tokens = dict)
 }
 
@@ -172,13 +183,14 @@ tokenlist_apply <- function(x, fun, arguments = NULL) {
   if (!is_tokenlist(x)) {
     rlang::abort("Input must be a tokenlist.")
   }
-  
+
   tokens <- get_tokens(x)
   apply_expr <- expr(lapply(tokens, fun))
-  
-  if (length(arguments) > 0)
+
+  if (length(arguments) > 0) {
     apply_expr <- mod_call_args(apply_expr, args = arguments)
-  
+  }
+
   tokenlist(eval(apply_expr))
 }
 
@@ -187,16 +199,18 @@ tokenlist_to_dtm <- function(x, dict) {
   if (!is_tokenlist(x)) {
     rlang::abort("Input must be a tokenlist.")
   }
-  
+
   tokens <- get_tokens(x)
   i <- rep(seq_along(tokens), lengths(tokens))
   j <- match(unlist(tokens), dict)
-  
-  out <- sparseMatrix(i = i[!is.na(j)],  
-                      j = j[!is.na(j)], 
-                      dims = c(length(tokens), length(dict)),
-                      x = 1)
-  
+
+  out <- sparseMatrix(
+    i = i[!is.na(j)],
+    j = j[!is.na(j)],
+    dims = c(length(tokens), length(dict)),
+    x = 1
+  )
+
   out@Dimnames[[2]] <- dict
   out
 }
@@ -205,11 +219,11 @@ tokenlist_lemma <- function(x) {
   if (!is_tokenlist(x)) {
     rlang::abort("Input must be a tokenlist.")
   }
-  
+
   if (is.null(maybe_get_lemma(x))) {
     rlang::abort("`lemma` attribute not avaliable.")
   }
-  
+
   tokenlist(maybe_get_lemma(x), pos = maybe_get_pos(x))
 }
 
@@ -217,25 +231,25 @@ tokenlist_pos_filter <- function(x, pos_tags) {
   if (!is_tokenlist(x)) {
     rlang::abort("Input must be a tokenlist.")
   }
-  
+
   if (is.null(maybe_get_pos(x))) {
     rlang::abort("pos attribute not avaliable.")
   }
-  
+
   tokens <- get_tokens(x)
   seq_x <- seq_along(tokens)
   i <- rep(seq_x, lengths(tokens))
   j <- match(unlist(maybe_get_pos(x)), pos_tags)
-  
+
   keep_id <- !is.na(j)
   split_id <- factor(i[keep_id], seq_x)
-  
+
   out <- split(unlist(get_tokens(x))[keep_id], split_id)
   names(out) <- NULL
-  
+
   pos <- split(unlist(maybe_get_pos(x))[keep_id], split_id)
   names(pos) <- NULL
-  
+
   lemma <- maybe_get_lemma(x)
   if (!is.null(lemma)) {
     lemma <- split(unlist(lemma)[keep_id], split_id)
@@ -243,7 +257,7 @@ tokenlist_pos_filter <- function(x, pos_tags) {
   } else {
     lemma <- NULL
   }
-  
+
   tokenlist(out, lemma = lemma, pos = pos)
 }
 
@@ -251,7 +265,7 @@ tokenlist_ngram <- function(x, n, n_min, delim) {
   if (!is_tokenlist(x)) {
     rlang::abort("Input must be a tokenlist.")
   }
-  
+
   tokenlist(rcpp_ngram(get_tokens(x), n, n_min, delim))
 }
 
@@ -261,10 +275,10 @@ tokenlist_embedding <- function(x, emb, fun) {
   i <- rep(seq_x, lengths(tokens))
   unlisted_tokens <- unlist(tokens)
   j <- match(unlisted_tokens, get_unique_tokens(x))
-  
+
   keep_id <- !is.na(j)
   split_id <- factor(i[keep_id], seq_x)
-  
+
   emb[match(unlisted_tokens, emb[[1]]), -1] %>%
     dplyr::mutate("id" = split_id) %>%
     tidyr::drop_na() %>%
