@@ -1,34 +1,37 @@
 library(recipes)
 
-eps <- if (capabilities("long.double"))
-  sqrt(.Machine$double.eps) else
-    0.1
+eps <- if (capabilities("long.double")) {
+  sqrt(.Machine$double.eps)
+} else {
+  0.1
+}
 
 # Set up the data that will be used in these tests. -----------------------
 
-test_data <- tibble(text = c("I would not eat them here or there.",
-                             "I would not eat them anywhere.",
-                             "I would not eat green eggs and ham.",
-                             "I do not like them, Sam-I-am.")
-)
+test_data <- tibble(text = c(
+  "I would not eat them here or there.",
+  "I would not eat them anywhere.",
+  "I would not eat green eggs and ham.",
+  "I do not like them, Sam-I-am."
+))
 
-rec_base <- recipe(~ ., data = test_data)
+rec_base <- recipe(~., data = test_data)
 
 # Create some manual data for expected results.
-tokens <- rec_base %>% 
+tokens <- rec_base %>%
   step_tokenize(text) %>%
   recipes::prep() %>%
-  recipes::juice() %>% 
-  vctrs::vec_cbind(rename(test_data, text1 = text)) %>% 
+  recipes::bake(new_data = NULL) %>%
+  vctrs::vec_cbind(rename(test_data, text1 = text)) %>%
   dplyr::select(text = text1, tokens = text)
 
 # Give each token an arbitrary value for comparison. Real embeddings will be
 # doubles, so make these double.
-embeddings <- tokens %>% 
+embeddings <- tokens %>%
   dplyr::mutate(tokens = vctrs::field(tokens, "tokens")) %>%
-  tidyr::unnest(tokens) %>% 
+  tidyr::unnest(tokens) %>%
   dplyr::distinct(tokens) %>%
-  dplyr::arrange(tokens) %>% 
+  dplyr::arrange(tokens) %>%
   # There are 17 unique tokens. We'll represent them with a 5-d set of vectors
   # so each one can be unique.
   dplyr::mutate(
@@ -41,61 +44,61 @@ embeddings <- tokens %>%
         )
       }
     )
-  ) %>% 
-  tidyr::unnest(token_num_binary) %>% 
+  ) %>%
+  tidyr::unnest(token_num_binary) %>%
   tidyr::pivot_wider(
     names_from = dimension,
     values_from = score
   )
 
-sentence_embeddings_long <- tokens %>% 
+sentence_embeddings_long <- tokens %>%
   dplyr::mutate(tokens = vctrs::field(tokens, "tokens")) %>%
-  tidyr::unnest(tokens) %>% 
+  tidyr::unnest(tokens) %>%
   dplyr::left_join(embeddings, by = "tokens")
 
 # Summarize by each statistic, and reorder to original order.
-sentence_embeddings_sum <- sentence_embeddings_long %>% 
-  dplyr::select(-tokens) %>% 
-  dplyr::group_by(text) %>% 
-  dplyr::summarize_all(sum) %>% 
+sentence_embeddings_sum <- sentence_embeddings_long %>%
+  dplyr::select(-tokens) %>%
+  dplyr::group_by(text) %>%
+  dplyr::summarize_all(sum) %>%
   dplyr::rename_if(
     is.numeric,
     ~ paste("w_embed", "sum", ., sep = "_")
   )
-sentence_embeddings_sum <- test_data %>% 
+sentence_embeddings_sum <- test_data %>%
   dplyr::left_join(sentence_embeddings_sum, by = "text")
 
-sentence_embeddings_mean <- sentence_embeddings_long %>% 
-  dplyr::select(-tokens) %>% 
-  dplyr::group_by(text) %>% 
-  dplyr::summarize_all(mean) %>% 
+sentence_embeddings_mean <- sentence_embeddings_long %>%
+  dplyr::select(-tokens) %>%
+  dplyr::group_by(text) %>%
+  dplyr::summarize_all(mean) %>%
   dplyr::rename_if(
     is.numeric,
     ~ paste("w_embed", "mean", ., sep = "_")
   )
-sentence_embeddings_mean <- test_data %>% 
+sentence_embeddings_mean <- test_data %>%
   dplyr::left_join(sentence_embeddings_mean, by = "text")
 
-sentence_embeddings_min <- sentence_embeddings_long %>% 
-  dplyr::select(-tokens) %>% 
-  dplyr::group_by(text) %>% 
-  dplyr::summarize_all(min) %>% 
+sentence_embeddings_min <- sentence_embeddings_long %>%
+  dplyr::select(-tokens) %>%
+  dplyr::group_by(text) %>%
+  dplyr::summarize_all(min) %>%
   dplyr::rename_if(
     is.numeric,
     ~ paste("w_embed", "min", ., sep = "_")
   )
-sentence_embeddings_min <- test_data %>% 
+sentence_embeddings_min <- test_data %>%
   dplyr::left_join(sentence_embeddings_min, by = "text")
 
-sentence_embeddings_max <- sentence_embeddings_long %>% 
-  dplyr::select(-tokens) %>% 
-  dplyr::group_by(text) %>% 
-  dplyr::summarize_all(max) %>% 
+sentence_embeddings_max <- sentence_embeddings_long %>%
+  dplyr::select(-tokens) %>%
+  dplyr::group_by(text) %>%
+  dplyr::summarize_all(max) %>%
   dplyr::rename_if(
     is.numeric,
     ~ paste("w_embed", "max", ., sep = "_")
   )
-sentence_embeddings_max <- test_data %>% 
+sentence_embeddings_max <- test_data %>%
   dplyr::left_join(sentence_embeddings_max, by = "text")
 
 rec <- rec_base %>%
@@ -105,12 +108,12 @@ rec <- rec_base %>%
 obj <- rec %>%
   prep()
 
-juiced <- juice(obj)
+juiced <- bake(obj, new_data = NULL)
 
 test_that("step_word_embeddings adds the appropriate number of columns.", {
   ncol_given <- ncol(embeddings) - 1L
-  ncol_juiced <- juiced %>% 
-    select(contains("w_embed_")) %>% 
+  ncol_juiced <- juiced %>%
+    select(contains("w_embed_")) %>%
     ncol()
   expect_identical(ncol_juiced, ncol_given)
 })
@@ -132,7 +135,7 @@ test_that("step_word_embeddings tidy method works.", {
   rec_tidied <- tidy(rec, 2)
   obj_tidied <- tidy(obj, 2)
   expected_cols <- c("terms", "embeddings_rows", "aggregation", "id")
-  
+
   expect_equal(dim(rec_tidied), c(1, 4))
   expect_equal(dim(obj_tidied), c(1, 4))
   expect_identical(colnames(rec_tidied), expected_cols)
@@ -144,51 +147,54 @@ test_that("step_word_embeddings tidy method works.", {
 test_that("step_word_embeddings aggregates vectors as expected.", {
   # By default, step_word_embeddings sums the vectors of the tokens it is given.
   expect_equal(
-    as.data.frame(juiced), 
+    as.data.frame(juiced),
     as.data.frame(select(sentence_embeddings_sum, -text)),
     tolerance = eps
   )
-  
+
   # Also allow the user to choose an aggregation function.
-  juiced_max <- rec_base %>% 
+  juiced_max <- rec_base %>%
     step_tokenize(text) %>%
     step_word_embeddings(
-      text, embeddings = embeddings, aggregation = "max"
-    ) %>% 
-    prep() %>% 
-    juice()
-  
+      text,
+      embeddings = embeddings, aggregation = "max"
+    ) %>%
+    prep() %>%
+    bake(new_data = NULL)
+
   expect_equal(
-    as.data.frame(juiced_max), 
-    as.data.frame(select(sentence_embeddings_max, -text)), 
+    as.data.frame(juiced_max),
+    as.data.frame(select(sentence_embeddings_max, -text)),
     tolerance = eps
   )
-  
-  juiced_min <- rec_base %>% 
+
+  juiced_min <- rec_base %>%
     step_tokenize(text) %>%
     step_word_embeddings(
-      text, embeddings = embeddings, aggregation = "min"
-    ) %>% 
-    prep() %>% 
-    juice()
-  
+      text,
+      embeddings = embeddings, aggregation = "min"
+    ) %>%
+    prep() %>%
+    bake(new_data = NULL)
+
   expect_equal(
-    as.data.frame(juiced_min), 
-    as.data.frame(select(sentence_embeddings_min, -text)), 
+    as.data.frame(juiced_min),
+    as.data.frame(select(sentence_embeddings_min, -text)),
     tolerance = eps
   )
-  
-  juiced_mean <- rec_base %>% 
+
+  juiced_mean <- rec_base %>%
     step_tokenize(text) %>%
     step_word_embeddings(
-      text, embeddings = embeddings, aggregation = "mean"
-    ) %>% 
-    prep() %>% 
-    juice()
-  
+      text,
+      embeddings = embeddings, aggregation = "mean"
+    ) %>%
+    prep() %>%
+    bake(new_data = NULL)
+
   expect_equal(
-    as.data.frame(juiced_mean), 
-    as.data.frame(select(sentence_embeddings_mean, -text)), 
+    as.data.frame(juiced_mean),
+    as.data.frame(select(sentence_embeddings_mean, -text)),
     tolerance = eps
   )
 })
@@ -208,12 +214,12 @@ test_that("step_word_embeddings deals with missing words appropriately.", {
     bake(obj, new_data = new_text),
     NA
   )
-  
+
   expect_warning(
     bake(obj, new_data = test_data),
     NA
   )
-  
+
   new_text <- tibble(
     text = "aksjdf nagjli aslkfa"
   )
@@ -239,7 +245,7 @@ test_that("NA tokens work.", {
   )
   test_result <- bake(obj, new_data = new_text)
   expected_result <- rbind(
-    bake(obj, new_data = new_text[1:2,]),
+    bake(obj, new_data = new_text[1:2, ]),
     c(0, 0, 0, 0, 0)
   )
   expect_identical(test_result, expected_result)
@@ -249,91 +255,98 @@ test_that("Embeddings work with empty documents", {
   empty_data <- data.frame(text = "")
 
   expect_equal(
-  recipe(~ text, data = empty_data) %>%
-    step_tokenize(text) %>%
-    step_word_embeddings(text, embeddings = embeddings, aggregation = "sum") %>%
-    prep() %>%
-    juice() %>% 
-    as.numeric(),
-  rep(0, 5)
+    recipe(~text, data = empty_data) %>%
+      step_tokenize(text) %>%
+      step_word_embeddings(text, embeddings = embeddings, aggregation = "sum") %>%
+      prep() %>%
+      bake(new_data = NULL) %>%
+      as.numeric(),
+    rep(0, 5)
   )
-  
+
   expect_equal(
-  recipe(~ text, data = empty_data) %>%
-    step_tokenize(text) %>%
-    step_word_embeddings(text, embeddings = embeddings, aggregation = "mean") %>%
-    prep() %>%
-    juice() %>% 
-    as.numeric(),
-  rep(0, 5)
+    recipe(~text, data = empty_data) %>%
+      step_tokenize(text) %>%
+      step_word_embeddings(text, embeddings = embeddings, aggregation = "mean") %>%
+      prep() %>%
+      bake(new_data = NULL) %>%
+      as.numeric(),
+    rep(0, 5)
   )
-  
+
   expect_equal(
-  recipe(~ text, data = empty_data) %>%
-    step_tokenize(text) %>%
-    step_word_embeddings(text, embeddings = embeddings, aggregation = "min") %>%
-    prep() %>%
-    juice() %>% 
-    as.numeric(),
-  rep(0, 5)
+    recipe(~text, data = empty_data) %>%
+      step_tokenize(text) %>%
+      step_word_embeddings(text, embeddings = embeddings, aggregation = "min") %>%
+      prep() %>%
+      bake(new_data = NULL) %>%
+      as.numeric(),
+    rep(0, 5)
   )
-  
+
   expect_equal(
-  recipe(~ text, data = empty_data) %>%
-    step_tokenize(text) %>%
-    step_word_embeddings(text, embeddings = embeddings, aggregation = "max") %>%
-    prep() %>%
-    juice() %>% 
-    as.numeric(),
-  rep(0, 5)
+    recipe(~text, data = empty_data) %>%
+      step_tokenize(text) %>%
+      step_word_embeddings(text, embeddings = embeddings, aggregation = "max") %>%
+      prep() %>%
+      bake(new_data = NULL) %>%
+      as.numeric(),
+    rep(0, 5)
   )
 })
 
 test_that("aggregation_default argument works", {
   empty_data <- data.frame(text = "")
-  
+
   expect_equal(
-    recipe(~ text, data = empty_data) %>%
+    recipe(~text, data = empty_data) %>%
       step_tokenize(text) %>%
-      step_word_embeddings(text, embeddings = embeddings, aggregation = "sum", 
-                           aggregation_default = 3) %>%
+      step_word_embeddings(text,
+        embeddings = embeddings, aggregation = "sum",
+        aggregation_default = 3
+      ) %>%
       prep() %>%
-      juice() %>% 
+      bake(new_data = NULL) %>%
       as.numeric(),
     rep(3, 5)
   )
-  
+
   expect_equal(
-    recipe(~ text, data = empty_data) %>%
+    recipe(~text, data = empty_data) %>%
       step_tokenize(text) %>%
-      step_word_embeddings(text, embeddings = embeddings, aggregation = "mean",
-                           aggregation_default = 3) %>%
+      step_word_embeddings(text,
+        embeddings = embeddings, aggregation = "mean",
+        aggregation_default = 3
+      ) %>%
       prep() %>%
-      juice() %>% 
+      bake(new_data = NULL) %>%
       as.numeric(),
     rep(3, 5)
   )
-  
+
   expect_equal(
-    recipe(~ text, data = empty_data) %>%
+    recipe(~text, data = empty_data) %>%
       step_tokenize(text) %>%
-      step_word_embeddings(text, embeddings = embeddings, aggregation = "min",
-                           aggregation_default = 3) %>%
+      step_word_embeddings(text,
+        embeddings = embeddings, aggregation = "min",
+        aggregation_default = 3
+      ) %>%
       prep() %>%
-      juice() %>% 
+      bake(new_data = NULL) %>%
       as.numeric(),
     rep(3, 5)
   )
-  
+
   expect_equal(
-    recipe(~ text, data = empty_data) %>%
+    recipe(~text, data = empty_data) %>%
       step_tokenize(text) %>%
-      step_word_embeddings(text, embeddings = embeddings, aggregation = "max",
-                           aggregation_default = 3) %>%
+      step_word_embeddings(text,
+        embeddings = embeddings, aggregation = "max",
+        aggregation_default = 3
+      ) %>%
       prep() %>%
-      juice() %>% 
+      bake(new_data = NULL) %>%
       as.numeric(),
     rep(3, 5)
   )
 })
-
