@@ -3,39 +3,42 @@ context("test-tokenize")
 library(textrecipes)
 library(recipes)
 
-test_data <- tibble(text = c("I would not eat them here or there.",
-                             "I would not eat them anywhere.",
-                             "I would not eat green eggs and ham.",
-                             "I do not like them, Sam-I-am.")
-                    )
+test_data <- tibble(text = c(
+  "I would not eat them here or there.",
+  "I would not eat them anywhere.",
+  "I would not eat green eggs and ham.",
+  "I do not like them, Sam-I-am."
+))
 
-rec <- recipe(~ ., data = test_data)
+rec <- recipe(~., data = test_data)
 
 test_that("output is list when length is 1 or 0", {
   data <- tibble(a = rep(c("a", ""), 20))
-  
-  data_rec <- recipe(~ ., data = data) %>%
+
+  data_rec <- recipe(~., data = data) %>%
     step_tokenize(a) %>%
     prep()
-  
+
   expect_true(is.list(juice(data_rec, a)[, 1, drop = TRUE]))
 })
 
 test_that("tokenization is done correctly", {
   rec <- rec %>%
-    step_tokenize(text) 
-  
+    step_tokenize(text)
+
   obj <- rec %>%
     prep()
-  
+
   expect_equal(
-    list(c("i", "would", "not", "eat", "them", "here", "or", "there"),
-         c("i", "would", "not", "eat", "them", "anywhere"),
-         c("i", "would", "not", "eat", "green", "eggs", "and", "ham"),
-         c("i", "do", "not", "like", "them", "sam", "i", "am")),
-    juice(obj) %>% pull(text) %>% vctrs::field("tokens")
+    list(
+      c("i", "would", "not", "eat", "them", "here", "or", "there"),
+      c("i", "would", "not", "eat", "them", "anywhere"),
+      c("i", "would", "not", "eat", "green", "eggs", "and", "ham"),
+      c("i", "do", "not", "like", "them", "sam", "i", "am")
+    ),
+    bake(obj, new_data = NULL) %>% pull(text) %>% vctrs::field("tokens")
   )
-  
+
   expect_equal(dim(recipes:::tidy.recipe(rec, 1)), c(1, 3))
   expect_equal(dim(recipes:::tidy.recipe(obj, 1)), c(1, 3))
 })
@@ -52,10 +55,10 @@ test_that("tokenization works with other built-in tokenizers", {
   rec <- rec %>%
     step_tokenize(text, token = "characters") %>%
     prep()
-  
+
   expect_equal(
     tokenizers::tokenize_characters(test_data$text[1]),
-    juice(rec) %>% slice(1) %>% pull(text) %>% vctrs::field("tokens")
+    bake(rec, new_data = NULL) %>% slice(1) %>% pull(text) %>% vctrs::field("tokens")
   )
 })
 
@@ -63,12 +66,12 @@ test_that("tokenization works with custom tokenizer", {
   rec <- rec %>%
     step_tokenize(text, custom_token = tokenizers::tokenize_characters) %>%
     prep()
-  
+
   expect_equal(
     tokenizers::tokenize_characters(test_data$text[1]),
-    juice(rec) %>% 
-      slice(1) %>% 
-      pull(text) %>% 
+    bake(rec, new_data = NULL) %>%
+      slice(1) %>%
+      pull(text) %>%
       vctrs::field("tokens")
   )
 })
@@ -77,13 +80,15 @@ test_that("arguments are passed using options argument", {
   rec <- rec %>%
     step_tokenize(text, options = list(lowercase = FALSE)) %>%
     prep()
-  
+
   expect_equal(
-    list(c("I", "would", "not", "eat", "them", "here", "or", "there"),
-         c("I", "would", "not", "eat", "them", "anywhere"),
-         c("I", "would", "not", "eat", "green", "eggs", "and", "ham"),
-         c("I", "do", "not", "like", "them", "Sam", "I", "am")),
-    juice(rec) %>% pull(text) %>% vctrs::field("tokens")
+    list(
+      c("I", "would", "not", "eat", "them", "here", "or", "there"),
+      c("I", "would", "not", "eat", "them", "anywhere"),
+      c("I", "would", "not", "eat", "green", "eggs", "and", "ham"),
+      c("I", "do", "not", "like", "them", "Sam", "I", "am")
+    ),
+    bake(rec, new_data = NULL) %>% pull(text) %>% vctrs::field("tokens")
   )
 })
 
@@ -98,24 +103,24 @@ test_that("tokenization errors with wrong engines", {
 test_that("tokenization includes lemma attribute when avaliable", {
   skip_on_cran()
   skip_if_no_python_or_no_spacy()
-  
+
   expect_type(
     rec %>%
       step_tokenize(text, engine = "spacyr") %>%
       prep() %>%
-      juice() %>%
+      bake(new_data = NULL) %>%
       .$text %>%
-      vctrs::field("lemma"), 
+      vctrs::field("lemma"),
     "list"
-    )
+  )
 })
-  
+
 test_that("tokenization doesn't includes lemma attribute when unavaliable", {
   expect_null(
     rec %>%
       step_tokenize(text) %>%
       prep() %>%
-      juice() %>%
+      bake(new_data = NULL) %>%
       .$text %>%
       attr("lemma")
   )
@@ -127,4 +132,3 @@ test_that("printing", {
   expect_output(print(rec))
   expect_output(prep(rec, verbose = TRUE))
 })
-
